/* Copyright (c) 1996 University of Utah.  All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for NON-COMMERCIAL purposes and without fee is
 * hereby granted provided that this copyright notice appears in all
 * copies.
 *
 * See http://www.cs.utah.edu/~hamlet for more educational resources.
 *
 * The University of Utah MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT
 * THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR
 * NON-INFRINGEMENT. The University of Utah SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package Interest;

public class Invest {

    static final int SIMPLE = 1;
    static final int COMPOUND = 2;
    static final int CONTINUOUS = 3;

    private int type;
    private double balance;
    private double rate;
    private int intervals;


    public Invest (int type, double balance, double rate) {
	this.type = type;
	this.balance = balance;
	this.rate = rate;
    }


    public Invest (int type, double balance, double rate, int intervals) {
	this.type = type;
	this.balance = balance;
	this.rate = rate;
	this.intervals = intervals;
    }


    public int steps (double years) {
	if (type == SIMPLE)
	    return((int) Math.ceil(years));
	if (type == COMPOUND)
	    return((int) Math.ceil(years*intervals));
	else
	    return(0);
    }


    public double compute (double years) {

	if (type == SIMPLE)
	    return(balance * Math.pow(1.0+rate/100, Math.round(years)));

	else if (type == COMPOUND)
	    return(balance * Math.pow(1.0+rate/(100.*intervals),
				      Math.round(years*intervals)));

	else if (type == CONTINUOUS)
	    return(balance * Math.exp(rate/100 * years));

	else
	    return(0);

    }
		   
		                      

    

    public String toString () {
	String desc = "$" + Double.toString(balance) +
	    " @ " + Double.toString(rate) + "% ";
	if (type == SIMPLE)
	    desc = desc + "simple";
	else if (type == CONTINUOUS)
	    desc = desc + "continuous";
	else if (type == COMPOUND)
	    desc = desc + "compound (" +
		Integer.toString(intervals) + ")";
	return(desc);
    }

}
